@@ -1,5 +1,5 @@
 package Text::ANSI::Fold::Util;
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 use v5.14;
 use utf8;
@@ -32,7 +32,7 @@ Text::ANSI::Fold::Util - Text::ANSI::Fold utilities (width, substr)
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =head1 DESCRIPTION
 
@@ -46,7 +46,7 @@ unexportable functions without them.
 
 Unless otherwise noted, these functions are executed in the same
 context as C<ansi_fold> exported by C<Text::ANSI::Fold> module. That
-is, the parameters set by C<Text::ANSI::Fold->configure> are
+is, the parameters set by C<< Text::ANSI::Fold->configure >> are
 effective.
 
 =over 7
@@ -94,10 +94,9 @@ sub substr {
     if ($offset < 0) {
 	$offset = max(0, $offset + ansi_width($text));
     }
-    state $fold = Text::ANSI::Fold->configure();
-    my @s = $fold
-	->configure(text => $text, width => [ $offset, $length // -1, -1 ])
-	->chops;
+    my @s = (state $fold = Text::ANSI::Fold->configure)
+	->text($text)
+	->chops(width => [ $offset, $length // -1, -1 ]);
     if (defined $replacement) {
 	$s[0] . $replacement . ($s[2] // '');
     } else {
